@@ -2,6 +2,7 @@ package Dancer::Plugin::Database;
 
 use strict;
 use Dancer::Plugin;
+use Dancer::Config;
 use DBI;
 use Dancer::Plugin::Database::Handle;
 
@@ -11,7 +12,7 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '1.11';
+our $VERSION = '1.20';
 
 my $settings = undef;
 
@@ -121,6 +122,28 @@ sub _get_connection {
         $dsn .= ':' . join(';', @extra_args) if @extra_args;
     }
 
+    # If the app is configured to use UTF-8, the user will want text from the
+    # database in UTF-8 to Just Work, so if we know how to make that happen, do
+    # so, unless they've set the auto_utf8 plugin setting to a false value.
+    my $app_charset = Dancer::Config::setting('charset');
+    my $auto_utf8 = exists $settings->{auto_utf8} ?  $settings->{auto_utf8} : 1;
+    if (lc $app_charset eq 'utf-8' && $auto_utf8) {
+        
+        # The option to pass to the DBI->connect call depends on the driver:
+        my %param_for_driver = (
+            SQLite => 'sqlite_unicode',
+            mysql  => 'mysql_enable_utf8',
+            Pg     => 'pg_enable_utf8',
+        );
+        if (my $param = $param_for_driver{ $settings->{driver} }) {
+            Dancer::Logger::debug(
+                "Adding $param to DBI connection params to enable UTF-8 support"
+            );
+            $settings->{dbi_params}{$param} = 1;
+        }
+    }
+
+
     my $dbh = DBI->connect($dsn, 
         $settings->{username}, $settings->{password}, $settings->{dbi_params}
     );
@@ -328,6 +351,17 @@ details to override any in the config file at runtime if desired, for instance:
 
 (Thanks to Alan Haggai for this feature.)
 
+=head1 AUTOMATIC UTF-8 SUPPORT
+
+As of version 1.20, if your application is configured to use UTF-8 (you've
+defined the C<charset> setting in your app config as C<UTF-8>) then support for
+UTF-8 for the database connection will be enabled, if we know how to do so for
+the database driver in use.
+
+If you do not want this behaviour, set C<auto_utf8> to a false value when
+providing the connection details.
+
+
 
 =head1 GETTING A DATABASE HANDLE
 
